# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nifi`](#nifi): Manage Apache NiFi

#### Private Classes

* `nifi::config`: Manage configuration for Apache NiFi
* `nifi::install`: Install Apache NiFi
* `nifi::service`: Manage the Apache NiFi service

## Classes

### <a name="nifi"></a>`nifi`

Install, configure and run Apache NiFi

#### Examples

##### Defaults

```puppet
include nifi
```

##### Downloading from a different repository

```puppet
class { 'nifi':
  version           => 'x.y.z',
  download_url      => 'https://my.local.repo.example.com/apache/nifi/nifi-x.y.z.tar.gz',
  download_checksum => 'abcde...',
}
```

#### Parameters

The following parameters are available in the `nifi` class:

* [`version`](#version)
* [`user`](#user)
* [`group`](#group)
* [`download_url`](#download_url)
* [`download_checksum`](#download_checksum)
* [`download_checksum_type`](#download_checksum_type)
* [`download_tmp_dir`](#download_tmp_dir)
* [`service_limit_nofile`](#service_limit_nofile)
* [`service_limit_nproc`](#service_limit_nproc)
* [`install_root`](#install_root)
* [`var_directory`](#var_directory)
* [`nifi_properties`](#nifi_properties)

##### <a name="version"></a>`version`

Data type: `String`

The version of Apache NiFi. This must match the version in the
tarball. This is used for managing files, directories and paths in
the service.

Default value: `'1.13.2'`

##### <a name="user"></a>`user`

Data type: `String`

The user owning the nifi installation files, and running the
service.

Default value: `'nifi'`

##### <a name="group"></a>`group`

Data type: `String`

The group owning the nifi installation files, and running the
service.

Default value: `'nifi'`

##### <a name="download_url"></a>`download_url`

Data type: `String`

Where to download the binary installation tarball from.

Default value: `'http://mirrors.ibiblio.org/apache/nifi/1.13.2/nifi-1.13.2-bin.tar.gz'`

##### <a name="download_checksum"></a>`download_checksum`

Data type: `String`

The expected checksum of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'1d4f5315e8bc04f68628e797cc1c674e8546d67e780e1a7fbdea9ca10a39cd2a'`

##### <a name="download_checksum_type"></a>`download_checksum_type`

Data type: `String`

The checksum type of the downloaded tarball. This is used for
verifying the integrity of the downloaded tarball.

Default value: `'sha256'`

##### <a name="download_tmp_dir"></a>`download_tmp_dir`

Data type: `Stdlib::Absolutepath`

Temporary directory for downloading the tarball.

Default value: `'/var/tmp'`

##### <a name="service_limit_nofile"></a>`service_limit_nofile`

Data type: `Integer`

The limit on number of open files permitted for the service. Used
for LimitNOFILE= in nifi.service.

Default value: `50000`

##### <a name="service_limit_nproc"></a>`service_limit_nproc`

Data type: `Integer`

The limit on number of processes permitted for the service. Used
for LimitNPROC= in nifi.service.

Default value: `10000`

##### <a name="install_root"></a>`install_root`

Data type: `Stdlib::Absolutepath`

The root directory of the nifi installation.

Default value: `'/opt/nifi'`

##### <a name="var_directory"></a>`var_directory`

Data type: `Stdlib::Absolutepath`

The root of the writable paths used by NiFi. Nifi will create
directories beneath this path.  This will implicitly add nifi
properties for working directories and repositories.

Default value: `'/var/opt/nifi'`

##### <a name="nifi_properties"></a>`nifi_properties`

Data type: `Hash`

Hash of parameter key/values to be added to conf/nifi.properties.

Default value: `{}`

